EXPORTS
	?Connect@RTestUtilSession@@QAEHXZ @ 1 NONAME ; int RTestUtilSession::Connect(void)
	?Copy@RTestUtilSession@@QAEHABVTDesC16@@0@Z @ 2 NONAME ; int RTestUtilSession::Copy(class TDesC16 const &, class TDesC16 const &)
	?Delete@RTestUtilSession@@QAEHABVTDesC16@@@Z @ 3 NONAME ; int RTestUtilSession::Delete(class TDesC16 const &)
	?FileExistsL@RTestUtilSession@@QAEHABVTDesC16@@@Z @ 4 NONAME ; int RTestUtilSession::FileExistsL(class TDesC16 const &)
	?FileExistsL@RTestUtilSession@@QAEHABVTDesC16@@H@Z @ 5 NONAME ; int RTestUtilSession::FileExistsL(class TDesC16 const &, int)
	?FormatDrive@RTestUtilSession@@QAEHHH@Z @ 6 NONAME ; int RTestUtilSession::FormatDrive(int, int)
	?GetFileHandle@RTestUtilSession@@QAEHABVTDesC16@@AAVRFile@@@Z @ 7 NONAME ; int RTestUtilSession::GetFileHandle(class TDesC16 const &, class RFile &)
	?GetNumFilesL@RTestUtilSession@@QAEHABVTDesC16@@@Z @ 8 NONAME ; int RTestUtilSession::GetNumFilesL(class TDesC16 const &)
	?Lock@RTestUtilSession@@QAEHABVTDesC16@@@Z @ 9 NONAME ; int RTestUtilSession::Lock(class TDesC16 const &)
	?MkDirAll@RTestUtilSession@@QAEHABVTDesC16@@@Z @ 10 NONAME ; int RTestUtilSession::MkDirAll(class TDesC16 const &)
	?MountDrive@RTestUtilSession@@QAEHH@Z @ 11 NONAME ; int RTestUtilSession::MountDrive(int)
	?Move@RTestUtilSession@@QAEHABVTDesC16@@0@Z @ 12 NONAME ; int RTestUtilSession::Move(class TDesC16 const &, class TDesC16 const &)
	?RmDir@RTestUtilSession@@QAEHABVTDesC16@@@Z @ 13 NONAME ; int RTestUtilSession::RmDir(class TDesC16 const &)
	?SetReadOnly@RTestUtilSession@@QAEHABVTDesC16@@H@Z @ 14 NONAME ; int RTestUtilSession::SetReadOnly(class TDesC16 const &, int)
	?UnMountDrive@RTestUtilSession@@QAEHH@Z @ 15 NONAME ; int RTestUtilSession::UnMountDrive(int)
	?Unlock@RTestUtilSession@@QAEHABVTDesC16@@@Z @ 16 NONAME ; int RTestUtilSession::Unlock(class TDesC16 const &)
	?WatchFile@RTestUtilSession@@QAEXABVTDesC16@@AAVTRequestStatus@@@Z @ 17 NONAME ; void RTestUtilSession::WatchFile(class TDesC16 const &, class TRequestStatus &)
	?WatchFileCancelL@RTestUtilSession@@QAEXXZ @ 18 NONAME ; void RTestUtilSession::WatchFileCancelL(void)
	?SetSecureClock@RTestUtilSession@@QAEHH@Z @ 19 NONAME ; int RTestUtilSession::SetSecureClock(int)

